@@ -1,3 +1,4 @@
+from lcconfig import ConsoleSettingsConfig
 import logging
 from pyzabbix import ZabbixMetric, ZabbixSender
 import socket
@@ -7,13 +8,15 @@ from typing import Iterable
 logger = logging.getLogger(__name__)
 
 
-def zabbix(packets: Iterable[tuple], key=None):
+def zabbix(packets: Iterable[tuple], host=None):
     """
     Send metrics back to Zabbix server.
     """
-    zabbix_key = key if key else socket.gethostname()
+    if not host:
+        cfg = ConsoleSettingsConfig().load().as_typed_dict('BoxData')
+        host = cfg.get('adminurl') or socket.gethostname()
 
-    packet = [ZabbixMetric(zabbix_key, key, str(value)) for key, value in packets]
+    packet = [ZabbixMetric(host, key, str(value)) for key, value in packets]
 
     dbos_location = '/run/zabbix/zabbix-agent2.conf'
     if Path(dbos_location).exists():
